==> py3-scikit-image-0.16.2p1.tgz: lib/python3.8/site-packages/skimage/filters/__init__.py <==
from .lpi_filter import inverse, wiener, LPIFilter2D
from ._gaussian import gaussian, _guess_spatial_dimensions
from .edges import (sobel, sobel_h, sobel_v,
                    scharr, scharr_h, scharr_v,
                    prewitt, prewitt_h, prewitt_v,
                    roberts, roberts_pos_diag, roberts_neg_diag,
                    laplace,
                    farid, farid_h, farid_v)
from ._rank_order import rank_order
from ._gabor import gabor_kernel, gabor
from .thresholding import (threshold_local, threshold_otsu, threshold_yen,
                           threshold_isodata, threshold_li, threshold_minimum,
                           threshold_mean, threshold_triangle,
                           threshold_niblack, threshold_sauvola,
                           threshold_multiotsu, try_all_threshold,
                           apply_hysteresis_threshold)
from .ridges import (meijering, sato, frangi, hessian)
from . import rank
from ._median import median
from ._unsharp_mask import unsharp_mask


__all__ = ['inverse',
           'wiener',
           'LPIFilter2D',
           'gaussian',
           'median',
           'sobel',
           'sobel_h',
           'sobel_v',
           'scharr',
           'scharr_h',
           'scharr_v',
           'prewitt',
           'prewitt_h',
           'prewitt_v',
           'roberts',
           'roberts_pos_diag',
           'roberts_neg_diag',
           'laplace',
           'rank_order',
           'gabor_kernel',
           'gabor',
           'try_all_threshold',
           'meijering',
           'sato',
           'frangi',
           'hessian',
           'threshold_otsu',
           'threshold_yen',
           'threshold_isodata',
           'threshold_li',
           'threshold_local',
           'threshold_minimum',
           'threshold_mean',
           'threshold_niblack',
           'threshold_sauvola',
           'threshold_triangle',
           'threshold_multiotsu',
           'apply_hysteresis_threshold',
           'rank',
           'unsharp_mask']

==> py3-scikit-image-0.17.2p2.tgz: lib/python3.9/site-packages/skimage/filters/__init__.py <==
from .lpi_filter import inverse, wiener, LPIFilter2D
from ._gaussian import (gaussian, _guess_spatial_dimensions,
                        difference_of_gaussians)
from .edges import (sobel, sobel_h, sobel_v,
                    scharr, scharr_h, scharr_v,
                    prewitt, prewitt_h, prewitt_v,
                    roberts, roberts_pos_diag, roberts_neg_diag,
                    laplace,
                    farid, farid_h, farid_v)
from ._rank_order import rank_order
from ._gabor import gabor_kernel, gabor
from .thresholding import (threshold_local, threshold_otsu, threshold_yen,
                           threshold_isodata, threshold_li, threshold_minimum,
                           threshold_mean, threshold_triangle,
                           threshold_niblack, threshold_sauvola,
                           threshold_multiotsu, try_all_threshold,
                           apply_hysteresis_threshold)
from .ridges import (meijering, sato, frangi, hessian)
from . import rank
from ._median import median
from ._unsharp_mask import unsharp_mask
from ._window import window


__all__ = ['inverse',
           'wiener',
           'LPIFilter2D',
           'gaussian',
           'difference_of_gaussians',
           'median',
           'sobel',
           'sobel_h',
           'sobel_v',
           'scharr',
           'scharr_h',
           'scharr_v',
           'prewitt',
           'prewitt_h',
           'prewitt_v',
           'roberts',
           'roberts_pos_diag',
           'roberts_neg_diag',
           'laplace',
           'rank_order',
           'gabor_kernel',
           'gabor',
           'try_all_threshold',
           'meijering',
           'sato',
           'frangi',
           'hessian',
           'threshold_otsu',
           'threshold_yen',
           'threshold_isodata',
           'threshold_li',
           'threshold_local',
           'threshold_minimum',
           'threshold_mean',
           'threshold_niblack',
           'threshold_sauvola',
           'threshold_triangle',
           'threshold_multiotsu',
           'apply_hysteresis_threshold',
           'rank',
           'unsharp_mask',
           'window']
